import 'package:flutter/material.dart';
import 'package:libcli/log/log.dart' as log;
import 'package:provider/provider.dart';
import 'package:libui/async/async_provider.dart';
import 'package:libui/async/await_provider.dart';

const _here = 'loading';

class Await extends StatelessWidget {
  final AwaitProvider provider = AwaitProvider();
  final Widget child;
  final Widget wait;
  final Widget error;

  Await(
      {Key key,
      @required List<AsyncProvider> list,
      @required this.child,
      this.wait,
      this.error})
      : super(key: key) {
    provider.list = list;
    provider.reload();
  }

  Widget errorView() {
    if (error != null) {
      return error;
    }
    String text;
    for (String s in provider.errorMessage()) {
      text += s + '\n';
    }
    return Center(child: Text(text));
  }

  Widget waitView() {
    if (wait != null) {
      return wait;
    }
    return Center(child: CircularProgressIndicator());
  }

  Widget widget(BuildContext context) {
    switch (provider.status()) {
      case AsyncStatus.ready:
        return child;
      case AsyncStatus.error:
        return errorView();
      default:
        return waitView();
    }
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: provider,
      child: widget(context),
    );
  }
}
