import 'package:flutter/material.dart';
import 'package:libcli/log/log.dart' as log;
import 'package:libui/i18n/i18n_state.dart';
import 'package:libcli/log/color.dart';

const _here = 'i18n';

//https://www.oracle.com/technical-resources/articles/javase/locale.html
const Locales = [
  'en_US',
  'en_CA',
  'en_GB',
  'en_AU',
  'zh_CN',
  'zh_TW',
  'zh_TW',
  'zh_TW',
  'zh_TW',
  'ja_JP',
  'it_IT',
  'de_DE',
];

String _localeID;

String _pageName;

I18nState _state;

get localeID => _localeID;

set localeID(String value) {
  _localeID = value;
  log.debug(_here, 'set locale=$_localeID');
}

get pageName => _pageName;

set pageName(String value) {
  _pageName = value;
  log.debug(_here, 'set page=$_pageName');
}

get state => _state;

set state(I18nState value) {
  _state = value;
  log.debug(_here, 'load $GREEN$_pageName ${RESET}with $_localeID');
}

String translate(String key) {
  assert(_state != null, 'need localzation before translate');
  return state.translate(key);
}

bool isSupportedLocale(Locale locale) {
  var id = localeToId(locale);
  var result = Locales.contains(id);
  return result;
}

String localeToId(Locale locale) {
  return '${locale.languageCode}_${locale.countryCode}';
}

Locale idToLocale(String id) {
  var ids = id.split('_');
  if (ids.length > 1) return Locale(ids[0], ids[1]);
  return Locale(ids[0]);
}

Locale determineLocale(List<Locale> locales) {
  log.debug(_here, 'determine best locale');
  print('determine Locale');
  for (var locale in locales) {
    if (isSupportedLocale(locale)) {
      log.debug(_here, 'choose ${locale.languageCode}_${locale.countryCode}');
      return locale;
    }
  }
  var locale = idToLocale(Locales[0]);
  log.debug(_here, 'use default ${locale.languageCode}_${locale.countryCode}');
  return locale;
}

List<Locale> supportedLocales() {
  log.debug(_here, 'ask supported locales');
  return Locales.map((id) => idToLocale(id)).toList();
}
