import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:libui/async/await.dart';
import 'package:provider/provider.dart';
import 'package:libui/i18n/i18n_provider.dart';
import 'package:libui/i18n/i18n_model.dart';
import 'package:libui/i18n/i18n.dart' as i18n;
import 'mock_views.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();
  setUp(() async {});

  group('[i18n_provider]', () {
    testWidgets('should load', (WidgetTester tester) async {
      i18n.pageName = 'mock';
      i18n.localeID = 'en_US';
      await tester.pumpWidget(MaterialApp(
        home: Material(
          child: TestWidget(),
        ),
      ));
      await tester.pumpAndSettle();
      expect(MockWaitView.count, greaterThan(0));
      expect(MockOkView.count, greaterThan(0));
      expect(I18nModelMock.page, 'mock');
      expect(I18nModelMock.locale, 'en_US');
    });
  });
}

class I18nModelMock extends I18nModel {
  static String page;
  static String locale;
  @override
  Future<void> read(String pageName, String localeID) async {
    page = pageName;
    locale = localeID;
  }
}

class TestWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider<I18nProvider>(
          create: (context) => I18nProvider(I18nModelMock()),
        ),
      ],
      child: Consumer<I18nProvider>(
          builder: (context, ctrl, child) => Await(
                list: [ctrl],
                wait: MockWaitView(),
                error: MockErrorView(),
                child: MockOkView(),
              )),
    );
  }
}
